[Mapbender-commits] r9220 - trunk/mapbender/http/classes
svn_mapbender at osgeo.org
svn_mapbender at osgeo.org
Mon Jun 22 08:50:34 PDT 2015
Author: armin11
Date: 2015-06-22 08:50:34 -0700 (Mon, 22 Jun 2015)
New Revision: 9220
Modified:
trunk/mapbender/http/classes/class_metadata_new.php
Log:
fix for storage of search results in cache
Modified: trunk/mapbender/http/classes/class_metadata_new.php
===================================================================
--- trunk/mapbender/http/classes/class_metadata_new.php 2015-06-22 11:18:24 UTC (rev 9219)
+++ trunk/mapbender/http/classes/class_metadata_new.php 2015-06-22 15:50:34 UTC (rev 9220)
@@ -842,12 +842,14 @@
$this->allJSON = new stdClass;
$this->allJSON->categories = $this->json->decode($this->keyJSON);
$this->allJSON->keywords = $this->json->decode($this->catJSON);
- //load filter from file
+ //load filter from file getFromStorage
+
$filename = $this->tempFolder."/".$this->searchId."_filter.json";
- if (!file_exists($filename)) {
+ $fileExists = $admin->getFromStorage($filename,TMP_SEARCH_RESULT_STORAGE);
+ if ($fileExists == false) {
$e = new mb_exception("class_metadata_new.php: No filter json exists!");
} else {
- $filterJSON = file_get_contents($filename);
+ $filterJSON = $fileExists;
$filterJSON = $this->json->decode($filterJSON);
$this->allJSON->filter = $filterJSON;
}
More information about the Mapbender_commits
mailing list